# Copyright (C) Internet Systems Consortium, Inc. ("ISC")
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, you can obtain one at https://mozilla.org/MPL/2.0/.
#
# See the COPYRIGHT file distributed with this work for additional
# information regarding copyright ownership.

rm -f nametoolong.out 
rm -f twoquestions.out 
rm -f noquestions.out 
rm -f ns*/named.conf
rm -f ns*/named.lock
rm -f ns*/named.run
rm -f ns*/named.memstats
